@@ -1,7 +1,11 @@
 """uWSGI cache backend"""
+__version__ = "0.3.0"
 
+try:
+    from django.utils.encoding import force_bytes as stringify
+except ImportError:
+    from django.utils.encoding import smart_str as stringify
 from django.core.cache.backends.base import BaseCache, InvalidCacheBackendError
-from django.utils.encoding import smart_str
 from django.conf import settings
 
 try:
@@ -11,7 +15,7 @@ except ImportError:
 
 try:
     import uwsgi
-except:
+except ImportError:
     if getattr(settings, "UWSGI_CACHE_FALLBACK", True):
         uwsgi = None
     else:
@@ -21,6 +25,7 @@ except:
             "to LocMemCache."
         )
 
+
 if uwsgi:
     class UWSGICache(BaseCache):
         def __init__(self, server, params):
@@ -29,9 +34,11 @@ if uwsgi:
             self._server = server
 
         def exists(self, key):
-            return self._cache.cache_exists(smart_str(key), self._server)
+            return self._cache.cache_exists(stringify(key), self._server)
 
-        def add(self, key, value, timeout=0, version=None):
+        def add(self, key, value, timeout=None, version=None):
+            if timeout is None:
+                timeout = self.default_timeout
             key = self.make_key(key, version=version)
             if self.exists(key):
                 return False
@@ -39,25 +46,26 @@ if uwsgi:
 
         def get(self, key, default=None, version=None):
             key = self.make_key(key, version=version)
-            val = self._cache.cache_get(smart_str(key), self._server)
+            val = self._cache.cache_get(stringify(key), self._server)
             if val is None:
                 return default
-            val = smart_str(val)
+            val = stringify(val)
             return pickle.loads(val)
 
-        def set(self, key, value, timeout=0, version=None):
+        def set(self, key, value, timeout=None, version=None):
+            if timeout is None:
+                timeout = self.default_timeout
             key = self.make_key(key, version=version)
-            self._cache.cache_update(smart_str(key), pickle.dumps(value), timeout, self._server)
+            self._cache.cache_update(stringify(key), pickle.dumps(value), timeout, self._server)
 
         def delete(self, key, version=None):
             key = self.make_key(key, version=version)
-            self._cache.cache_del(smart_str(key), self._server)
+            self._cache.cache_del(stringify(key), self._server)
 
         def close(self, **kwargs):
             pass
 
         def clear(self):
-            pass
+            self._cache.cache_clear(self._server)
 else:
-    from django.core.cache.backends.locmem import LocMemCache as UWSGICache
-    from django.core.cache.backends import locmem
+    from django.core.cache.backends.locmem import LocMemCache as UWSGICache # flake8: noqa
